Video Analysis {#tutorial_py_table_of_contents_video}
==============

-   @subpage tutorial_py_meanshift

    We have already seen
    an example of color-based tracking. It is simpler. This time, we see significantly better
    algorithms like "Meanshift", and its upgraded version, "Camshift" to find and track them.

-   @subpage tutorial_py_lucas_kanade

    Now let's discuss an important concept, "Optical Flow", which is related to videos and has many applications.

-   @subpage tutorial_py_bg_subtraction

    In several applications, we need to extract foreground for further operations like object tracking. Background Subtraction is a well-known method in those cases.
